@@ -146,10 +146,11 @@
 #define OFFT2NUM(v) LL2NUM(v)
 #define NUM2OFFT(v) NUM2LL(v)
 #define PRI_OFFT_PREFIX PRI_LL_PREFIX
-#define rb_clockid_t int
-#define SIGNEDNESS_OF_CLOCKID_T -1
-#define CLOCKID2NUM(v) INT2NUM(v)
-#define NUM2CLOCKID(v) NUM2INT(v)
+#define HAVE_CLOCKID_T 1
+#define rb_clockid_t clockid_t
+#define SIGNEDNESS_OF_CLOCKID_T +1
+#define CLOCKID2NUM(v) UINT2NUM(v)
+#define NUM2CLOCKID(v) NUM2UINT(v)
 #define PRI_CLOCKID_PREFIX PRI_INT_PREFIX
 #define HAVE_VA_ARGS_MACRO 1
 #define HAVE__ALIGNOF 1
@@ -266,6 +267,7 @@
 #define HAVE_CHMOD 1
 #define HAVE_CHOWN 1
 #define HAVE_CHROOT 1
+#define HAVE_CLOCK_GETTIME 1
 #define HAVE_COSH 1
 #define HAVE_DIRFD 1
 #define HAVE_DLOPEN 1
@@ -289,6 +291,7 @@
 #define HAVE_GETATTRLIST 1
 #define HAVE_GETCWD 1
 #define HAVE_GETEGID 1
+#define HAVE_GETENTROPY 1
 #define HAVE_GETEUID 1
 #define HAVE_GETGID 1
 #define HAVE_GETGRNAM 1
@@ -309,7 +312,6 @@
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GETUID 1
 #define HAVE_GMTIME_R 1
-#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_ISSETUGID 1
@@ -379,6 +381,7 @@
 #define HAVE_TZSET 1
 #define HAVE_UMASK 1
 #define HAVE_UNSETENV 1
+#define HAVE_UTIMENSAT 1
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
@@ -395,18 +398,21 @@
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CTZ 1
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
-#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define HAVE_BUILTIN___BUILTIN_EXPECT 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
+#define USE___BUILTIN_ADD_OVERFLOW_LONG_LONG 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
+#define USE___BUILTIN_SUB_OVERFLOW_LONG_LONG 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
 #define USE___BUILTIN_MUL_OVERFLOW_LONG_LONG 1
 #define HAVE_BSD_QSORT_R 1
 #define ATAN2_INF_C99 1
+#define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -445,13 +451,15 @@
 #define BROKEN_BACKTRACE 1
 #define DLEXT_MAXLEN 7
 #define DLEXT ".bundle"
+#define SOEXT ".dylib"
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
-#define HAVE_SIGSETJMP 1
-#define RUBY_SETJMP(env) sigsetjmp((env),0)
-#define RUBY_LONGJMP(env,val) siglongjmp((env),val)
-#define RUBY_JMP_BUF sigjmp_buf
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
+#define RUBY_JMP_BUF jmp_buf
+#define USE_MODULAR_GC 0
 #define USE_YJIT 0
 #define USE_RJIT 0
 #define RUBY_PLATFORM "x86_64-darwin15"
+#define RB_DEFAULT_PARSER RB_DEFAULT_PARSER_PRISM
 #endif /* INCLUDE_RUBY_CONFIG_H */
